---
title: 'antispam:plugin:dcc'
url: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-dcc'
markdown: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-dcc.md'
date: '2026-09-24'
description: 'DCC is a system of servers counting checksums of millions of mail messages to determine whether a message is bulk email or not. warden --task=antispam:plugin:dcc Option Value Default Description --use_dcc <1|0> 0 Use DCC, if it is available. --use_dcc_rep <1|0> 1 Use …'
taxonomy:
  category:
    - docs
  tag:
    - dcc
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Antispam       antispam:plugin:dcc    

# antispam:plugin:dcc

DCC is a system of servers counting checksums of millions of mail messages to determine whether a message is bulk email or not.

```
warden --task=antispam:plugin:dcc
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--use_dcc` | <1\|0> | 0 | Use DCC, if it is available. |
| `--use_dcc_rep` | <1\|0> | 1 | Use DCC Reputations. Note that reputation data is free for all starting from the DCC 2.x version, where it's automatically used. Read more: <https://www.rhyolite.com/dcc/reputations.shtml> |
| `--dcc_timeout` | <1\|0> | 8 | How long you wait for DCC to complete, before scanning continues without the DCC results. A numeric value can optionally be suffixed with a time unit (s, m, h, d, w; seconds is the default). |
| `--dcc_body_max` | <digit> | 999999 | Sets how often a messages body checksum must have been reported to the DCC server before SpamAssassin will consider the DCC check hit. `999999` is DCC's MANY count. |
| `--dcc_fuz1_max` | <digit> | 999999 | Sets how often a messages fuz1 checksum must have been reported to the DCC server before SpamAssassin will consider the DCC check hit. `999999` is DCC's MANY count. |
| `--dcc_fuz2_max` | <digit> | 999999 | Sets how often a messages fuz2 checksum must have been reported to the DCC server before SpamAssassin will consider the DCC check hit. `999999` is DCC's MANY count. |
| `--dcc_rep_percent` | <digit> | 90 | A DCC Reputation is the percentage of bulk mail received from the last untrusted relay in the path taken by a mail message, as measured by all commercial DCC installations. Since DCC 2.x, reputation data is available to all users and used automatically. You must whitelist your trusted relays or MX servers with MX or MXDCC lines in /var/lib/dcc/whiteclnt as described in the main DCC man page to avoid seeing your own MX servers as sources of bulk mail. |
| `--dcc_learn_score` | <int> |  | Report messages with total scores this much larger than the SpamAssassin spam threshold to DCC as spam. |
| `--dcc_home` | <string> | /var/lib/dcc | Tells SpamAssassin specifically where to find the dcc homedir. If dcc\_path is not specified, it will default to looking in dcc\_home/bin for dcc client instead of relying on SpamAssassin to find it in the current PATH. If it is not found there, it will look in the current PATH. |
| `--dcc_path` | <string> | /usr/bin/dccproc | Tells SpamAssassin specifically where to find the dccproc client instead of relying on SpamAssassin to find it in the current PATH. |
| `--dcc_options` | <string> |  | Specify additional options to the dccproc command. Please note that only characters in the range \[0-9A-Za-z ,.\_/-\] are allowed for security reasons. |
| `--dcc_dccifd_path` | <string> |  | Tells SpamAssassin where to find the dccifd socket instead of a local Unix socket named dccifd in the dcc\_home directory. If a socket is specified or found, use it instead of dccproc. |
| `--dccifd_options` | <string> |  | Specify additional options to send to the dccifd daemon with the ASCII protocol described on the dccifd(8) man page. Only characters in the range \[0-9A-Za-z ,.\_/-\] are allowed for security reasons. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |
| `--reload` | <yes> |  | Reload the service after saving settings. |

## Examples

```
// set the dcc_timeout
warden --task=antispam:plugin:dcc --dcc_timeout=5 --reload=yes

// reset dcc_timeout to its default value
warden --task=antispam:plugin:dcc --default_option=dcc_timeout --reload=yes

// reset all settings to their default values
warden --task=antispam:plugin:dcc --default=yes --reload=yes
```

## Related Pages

- [DCC Settings](https://docs.danami.com/warden/settings/antispam/plugin-settings/dcc "DCC Settings")
- [DCC](https://docs.danami.com/warden/user-guide/antispam-plugins/dcc "DCC")

 [ ](https://docs.danami.com/warden/user-guide/antispam-plugins/dcc) [](https://docs.danami.com/warden/settings/antispam/plugin-settings/dcc)

---

## Navigation

- Previous: [antispam:plugin:awl](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-awl.md)
- Next: [antispam:plugin:decodeshorturls](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-decodeshorturls.md)
